summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:21 -0600
commitb6ba5d642f3fc7d320e3d6f4650eb259a3a52b04 (patch)
tree76f49820693d443128d3720322ff1605e9bcd558 /languages/cpp/debugger
parent247f828db1b8dcdc9346c1568d81cfa00db99c9e (diff)
downloadtdevelop-b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.tar.gz
tdevelop-b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'languages/cpp/debugger')
-rw-r--r--languages/cpp/debugger/TODO.txt2
-rw-r--r--languages/cpp/debugger/breakpoint.cpp10
-rw-r--r--languages/cpp/debugger/dbgcontroller.h2
-rw-r--r--languages/cpp/debugger/dbgpsdlg.cpp6
-rw-r--r--languages/cpp/debugger/dbgtoolbar.cpp42
-rw-r--r--languages/cpp/debugger/dbgtoolbar.h2
-rw-r--r--languages/cpp/debugger/debuggerconfigwidget.cpp2
-rw-r--r--languages/cpp/debugger/debuggerconfigwidgetbase.ui8
-rw-r--r--languages/cpp/debugger/debuggerpart.cpp34
-rw-r--r--languages/cpp/debugger/debuggerpart.h2
-rw-r--r--languages/cpp/debugger/debuggertracingdialogbase.ui2
-rw-r--r--languages/cpp/debugger/disassemblewidget.cpp2
-rw-r--r--languages/cpp/debugger/disassemblewidget.h2
-rw-r--r--languages/cpp/debugger/framestackwidget.cpp16
-rw-r--r--languages/cpp/debugger/gdbbreakpointwidget.cpp28
-rw-r--r--languages/cpp/debugger/gdbcommand.cpp2
-rw-r--r--languages/cpp/debugger/gdbcontroller.cpp58
-rw-r--r--languages/cpp/debugger/gdbcontroller.h2
-rw-r--r--languages/cpp/debugger/gdboutputwidget.cpp18
-rw-r--r--languages/cpp/debugger/gdboutputwidget.h4
-rw-r--r--languages/cpp/debugger/memviewdlg.cpp20
-rw-r--r--languages/cpp/debugger/variablewidget.cpp108
-rw-r--r--languages/cpp/debugger/variablewidget.h20
23 files changed, 196 insertions, 196 deletions
diff --git a/languages/cpp/debugger/TODO.txt b/languages/cpp/debugger/TODO.txt
index 563cf85c..38aca109 100644
--- a/languages/cpp/debugger/TODO.txt
+++ b/languages/cpp/debugger/TODO.txt
@@ -69,7 +69,7 @@ TODO:
- Add icons
- - tqStatus display column is just ugly
+ - Status display column is just ugly
- Handle "out of breakpoints" message.
diff --git a/languages/cpp/debugger/breakpoint.cpp b/languages/cpp/debugger/breakpoint.cpp
index c42f32c9..1b6efdaf 100644
--- a/languages/cpp/debugger/breakpoint.cpp
+++ b/languages/cpp/debugger/breakpoint.cpp
@@ -213,7 +213,7 @@ bool Breakpoint::match(const Breakpoint* breakpoint) const
TQString Breakpoint::dbgRemoveCommand() const
{
if (dbgId_>0)
- return TQString("-break-delete %1").tqarg(dbgId_); // gdb command - not translatable
+ return TQString("-break-delete %1").arg(dbgId_); // gdb command - not translatable
return TQString();
}
@@ -386,7 +386,7 @@ FilePosBreakpoint::FilePosBreakpoint(const TQString &fileName, int lineNum,
: Breakpoint(temporary, enabled)
{
// Sets 'subtype'
- setLocation(TQString("%1:%2").tqarg(fileName).tqarg(lineNum));
+ setLocation(TQString("%1:%2").arg(fileName).arg(lineNum));
}
FilePosBreakpoint::~FilePosBreakpoint()
@@ -482,7 +482,7 @@ void FilePosBreakpoint::setLocation(const TQString& location)
line_ = regExp1.cap(2).toInt();
- location_ = TQString("%1:%2").tqarg(fileName_).tqarg(regExp1.cap(2));
+ location_ = TQString("%1:%2").arg(fileName_).arg(regExp1.cap(2));
}
else
{
@@ -536,7 +536,7 @@ void Watchpoint::setBreakpoint(GDBController* controller)
controller->addCommandBeforeRun(
new GDBCommand(
- TQString("-data-evaluate-expression &%1").tqarg(varName_),
+ TQString("-data-evaluate-expression &%1").arg(varName_),
this,
&Watchpoint::handleAddressComputed));
}
@@ -547,7 +547,7 @@ void Watchpoint::handleAddressComputed(const GDBMI::ResultRecord& r)
address_ = r["value"].literal().toULongLong(0, 16);
controller()->addCommandBeforeRun(
new GDBCommand(
- TQString("-break-watch *%1").tqarg(r["value"].literal()),
+ TQString("-break-watch *%1").arg(r["value"].literal()),
static_cast<Breakpoint*>(this),
&Watchpoint::handleSet));
}
diff --git a/languages/cpp/debugger/dbgcontroller.h b/languages/cpp/debugger/dbgcontroller.h
index c87a333f..f8103ab2 100644
--- a/languages/cpp/debugger/dbgcontroller.h
+++ b/languages/cpp/debugger/dbgcontroller.h
@@ -118,7 +118,7 @@ signals:
void gdbUserCommandStdout (const char *output);
void gdbStderr (const char *output);
void showStepInSource (const TQString &fileName, int lineNum, const TQString &address);
- void dbgtqStatus (const TQString &status, int statusFlag);
+ void dbgStatus (const TQString &status, int statusFlag);
protected:
KProcess *dbgProcess_;
diff --git a/languages/cpp/debugger/dbgpsdlg.cpp b/languages/cpp/debugger/dbgpsdlg.cpp
index c31f4a4c..22c85502 100644
--- a/languages/cpp/debugger/dbgpsdlg.cpp
+++ b/languages/cpp/debugger/dbgpsdlg.cpp
@@ -28,7 +28,7 @@
#include <tqframe.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqtoolbutton.h>
#include <tqpushbutton.h>
@@ -77,7 +77,7 @@ Dbg_PS_Dialog::Dbg_PS_Dialog(TQWidget *parent, const char *name)
buttonbox->addStretch();
TQPushButton *ok = buttonbox->addButton(KStdGuiItem::ok());
TQPushButton *cancel = buttonbox->addButton(KStdGuiItem::cancel());
- buttonbox->tqlayout();
+ buttonbox->layout();
topLayout->addWidget(buttonbox);
connect(ok, TQT_SIGNAL(clicked()), TQT_SLOT(accept()));
@@ -172,7 +172,7 @@ void Dbg_PS_Dialog::slotProcessExited()
// to 'arg'.
i18n("<b>Could not parse output from the <tt>ps</tt> command.</b>"
"<p>The following line could not be parsed:"
- "<b><tt>%1</tt>").tqarg(item),
+ "<b><tt>%1</tt>").arg(item),
i18n("Internal error"), "gdb_error" );
break;
}
diff --git a/languages/cpp/debugger/dbgtoolbar.cpp b/languages/cpp/debugger/dbgtoolbar.cpp
index e8bb0c90..435591a3 100644
--- a/languages/cpp/debugger/dbgtoolbar.cpp
+++ b/languages/cpp/debugger/dbgtoolbar.cpp
@@ -28,7 +28,7 @@
#include <tqapplication.h>
#include <tqcursor.h>
#include <tqframe.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqpushbutton.h>
#include <tqtooltip.h>
@@ -120,8 +120,8 @@ void DbgMoveHandle::mousePressEvent(TQMouseEvent *e)
offset_ = parentWidget()->pos() - e->globalPos();
setFrameStyle(TQFrame::Panel|TQFrame::Sunken);
TQApplication::setOverrideCursor(TQCursor(sizeAllCursor));
- setPalette(TQPalette(tqcolorGroup().background()));
- tqrepaint();
+ setPalette(TQPalette(colorGroup().background()));
+ repaint();
}
}
@@ -134,8 +134,8 @@ void DbgMoveHandle::mouseReleaseEvent(TQMouseEvent *e)
offset_ = TQPoint(0,0);
setFrameStyle(TQFrame::Panel|TQFrame::Raised);
TQApplication::restoreOverrideCursor();
- setPalette(TQPalette(tqcolorGroup().background()));
- tqrepaint();
+ setPalette(TQPalette(colorGroup().background()));
+ repaint();
}
// **************************************************************************
@@ -162,7 +162,7 @@ public:
DbgToolBar *parent, const char *name=0);
virtual ~DbgButton() {};
void drawButtonLabel(TQPainter *painter);
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
private:
TQPixmap pixmap_;
@@ -191,21 +191,21 @@ void DbgButton::drawButtonLabel(TQPainter *painter)
painter->drawPixmap(x, y, pixmap_);
if (hasText) {
- painter->setPen(tqcolorGroup().text());
+ painter->setPen(colorGroup().text());
painter->drawText(height()+2, 0, width()-(height()+2), height(), AlignLeft|AlignVCenter, text());
}
}
// **************************************************************************
-TQSize DbgButton::tqsizeHint() const
+TQSize DbgButton::sizeHint() const
{
if (text().isEmpty())
return pixmap_.size();
else
{
TQSize ps = pixmap_.size();
- TQSize bs = TQPushButton::tqsizeHint();
+ TQSize bs = TQPushButton::sizeHint();
TQSize result;
result.setWidth( ps.width() + bs.width()+10 );
result.setHeight( ps.height() > bs.height() ? ps.height() : bs.height() );
@@ -365,12 +365,12 @@ DbgToolBar::DbgToolBar(DebuggerPart* part,
nextLayout->addWidget(bNext);
nextLayout->addWidget(bNexti);
-// int w = TQMAX(bRun->tqsizeHint().width(), bFinish->tqsizeHint().width());
-// w = TQMAX(w, bInterrupt->tqsizeHint().width());
-// w = TQMAX(w, bView->tqsizeHint().width());
+// int w = TQMAX(bRun->sizeHint().width(), bFinish->sizeHint().width());
+// w = TQMAX(w, bInterrupt->sizeHint().width());
+// w = TQMAX(w, bView->sizeHint().width());
// they should have the same height, so don't be too fussy
-// int h = bFinish->tqsizeHint().height();
+// int h = bFinish->sizeHint().height();
//
// bNext->setMinimumHeight(h);
// bNexti->setMinimumHeight(h);
@@ -404,10 +404,10 @@ void DbgToolBar::slotKdevFocus()
// If anyone has a way of determining what window the app is _actually_ running on
// then please fix and send a patch.
- if (winModule_->activeWindow() != tqtopLevelWidget()->winId())
+ if (winModule_->activeWindow() != topLevelWidget()->winId())
activeWindow_ = winModule_->activeWindow();
- KWin::activateWindow(tqtopLevelWidget()->winId());
+ KWin::activateWindow(topLevelWidget()->winId());
}
// **************************************************************************
@@ -421,7 +421,7 @@ void DbgToolBar::slotPrevFocus()
// If the app is active then the app button is highlighted, otherwise
// kdev button is highlighted.
-void DbgToolBar::slotDbgtqStatus(const TQString&, int state)
+void DbgToolBar::slotDbgStatus(const TQString&, int state)
{
bool appIndicator = state & s_dbgBusy;
if (appIndicator != appIsActive_) {
@@ -435,11 +435,11 @@ void DbgToolBar::slotDbgtqStatus(const TQString&, int state)
void DbgToolBar::setAppIndicator(bool appIndicator)
{
if (appIndicator) {
- bPrevFocus_->setPalette(TQPalette(tqcolorGroup().mid()));
- bKDevFocus_->setPalette(TQPalette(tqcolorGroup().background()));
+ bPrevFocus_->setPalette(TQPalette(colorGroup().mid()));
+ bKDevFocus_->setPalette(TQPalette(colorGroup().background()));
} else {
- bPrevFocus_->setPalette(TQPalette(tqcolorGroup().background()));
- bKDevFocus_->setPalette(TQPalette(tqcolorGroup().mid()));
+ bPrevFocus_->setPalette(TQPalette(colorGroup().background()));
+ bKDevFocus_->setPalette(TQPalette(colorGroup().mid()));
}
}
@@ -487,7 +487,7 @@ void DbgToolBar::slotActivateAndUndock()
if (!docked_)
return;
- KWin::activateWindow(tqtopLevelWidget()->winId());
+ KWin::activateWindow(topLevelWidget()->winId());
slotUndock();
}
diff --git a/languages/cpp/debugger/dbgtoolbar.h b/languages/cpp/debugger/dbgtoolbar.h
index 5e1424d7..7f124c6c 100644
--- a/languages/cpp/debugger/dbgtoolbar.h
+++ b/languages/cpp/debugger/dbgtoolbar.h
@@ -58,7 +58,7 @@ public:
virtual ~DbgToolBar();
private slots:
- void slotDbgtqStatus(const TQString&, int);
+ void slotDbgStatus(const TQString&, int);
void slotDock();
void slotUndock();
void slotIconifyAndDock();
diff --git a/languages/cpp/debugger/debuggerconfigwidget.cpp b/languages/cpp/debugger/debuggerconfigwidget.cpp
index d4c97957..05a8cf78 100644
--- a/languages/cpp/debugger/debuggerconfigwidget.cpp
+++ b/languages/cpp/debugger/debuggerconfigwidget.cpp
@@ -78,7 +78,7 @@ DebuggerConfigWidget::DebuggerConfigWidget(DebuggerPart* part, TQWidget *parent,
// ??? DomUtil::readEntry(dom, "/kdevdebugger/general/allowforcedbpset");
- resize(tqsizeHint());
+ resize(sizeHint());
}
diff --git a/languages/cpp/debugger/debuggerconfigwidgetbase.ui b/languages/cpp/debugger/debuggerconfigwidgetbase.ui
index a3a1e321..72bb4c93 100644
--- a/languages/cpp/debugger/debuggerconfigwidgetbase.ui
+++ b/languages/cpp/debugger/debuggerconfigwidgetbase.ui
@@ -102,7 +102,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -208,7 +208,7 @@ check this option.</string>
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<vbox>
<property name="name">
@@ -303,7 +303,7 @@ check this option.</string>
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<grid>
<property name="name">
@@ -404,7 +404,7 @@ or if your executable contains the gdb stub
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
diff --git a/languages/cpp/debugger/debuggerpart.cpp b/languages/cpp/debugger/debuggerpart.cpp
index 59294487..fb1577d4 100644
--- a/languages/cpp/debugger/debuggerpart.cpp
+++ b/languages/cpp/debugger/debuggerpart.cpp
@@ -92,7 +92,7 @@ DebuggerPart::DebuggerPart( TQObject *parent, const char *name, const TQStringLi
statusBarIndicator = new LabelWithDoubleClick(
" ", mainWindow()->statusBar());
statusBarIndicator->setFixedWidth(15);
- statusBarIndicator->tqsetAlignment(TQt::AlignCenter);
+ statusBarIndicator->setAlignment(TQt::AlignCenter);
mainWindow()->statusBar()->addWidget(statusBarIndicator, 0, true);
statusBarIndicator->show();
@@ -500,7 +500,7 @@ void DebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
this, TQT_SLOT(slotRunToCursor()),
0, -1, index);
- popup->tqsetWhatsThis(id, act->whatsThis());
+ popup->setWhatsThis(id, act->whatsThis());
index += running;
}
}
@@ -510,21 +510,21 @@ void DebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
this, TQT_SLOT(toggleBreakpoint()),
0, -1, index);
index += running;
- popup->tqsetWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Toggles breakpoint at the current line."));
+ popup->setWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Toggles breakpoint at the current line."));
}
if (!m_contextIdent.isEmpty())
{
TQString squeezed = KStringHandler::csqueeze(m_contextIdent, 30);
- int id = popup->insertItem( i18n("Evaluate: %1").tqarg(squeezed),
+ int id = popup->insertItem( i18n("Evaluate: %1").arg(squeezed),
this, TQT_SLOT(contextEvaluate()),
0, -1, index);
index += running;
- popup->tqsetWhatsThis(id, i18n("<b>Evaluate expression</b><p>Shows the value of the expression under the cursor."));
- int id2 = popup->insertItem( i18n("Watch: %1").tqarg(squeezed),
+ popup->setWhatsThis(id, i18n("<b>Evaluate expression</b><p>Shows the value of the expression under the cursor."));
+ int id2 = popup->insertItem( i18n("Watch: %1").arg(squeezed),
this, TQT_SLOT(contextWatch()),
0, -1, index);
index += running;
- popup->tqsetWhatsThis(id2, i18n("<b>Watch expression</b><p>Adds an expression under the cursor to the Variables/Watch list."));
+ popup->setWhatsThis(id2, i18n("<b>Watch expression</b><p>Adds an expression under the cursor to the Variables/Watch list."));
}
if (running)
popup->insertSeparator(index);
@@ -589,8 +589,8 @@ void DebuggerPart::setupController()
disassembleWidget, TQT_SLOT(slotShowStepInSource(const TQString&, int, const TQString&)));
// controller -> this
- connect( controller, TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
- this, TQT_SLOT(slottqStatus(const TQString&, int)));
+ connect( controller, TQT_SIGNAL(dbgStatus(const TQString&, int)),
+ this, TQT_SLOT(slotStatus(const TQString&, int)));
connect( controller, TQT_SIGNAL(showStepInSource(const TQString&, int, const TQString&)),
this, TQT_SLOT(slotShowStep(const TQString&, int)));
connect( controller, TQT_SIGNAL(debuggerAbnormalExit()),
@@ -613,16 +613,16 @@ void DebuggerPart::setupController()
connect( controller, TQT_SIGNAL(gdbStderr(const char*)),
gdbOutputWidget, TQT_SLOT(slotReceivedStderr(const char*)) );
- connect( controller, TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
- gdbOutputWidget, TQT_SLOT(slotDbgtqStatus(const TQString&, int)));
+ connect( controller, TQT_SIGNAL(dbgStatus(const TQString&, int)),
+ gdbOutputWidget, TQT_SLOT(slotDbgStatus(const TQString&, int)));
// controller -> viewerWidget
- connect( controller, TQT_SIGNAL(dbgtqStatus(const TQString&, int)),
+ connect( controller, TQT_SIGNAL(dbgStatus(const TQString&, int)),
viewerWidget, TQT_SLOT(slotDebuggerState(const TQString&, int)));
connect(statusBarIndicator, TQT_SIGNAL(doubleClicked()),
- controller, TQT_SLOT(explainDebuggertqStatus()));
+ controller, TQT_SLOT(explainDebuggerStatus()));
}
@@ -659,7 +659,7 @@ bool DebuggerPart::startDebugger()
{
KMessageBox::information(
mainWindow()->main(),
- i18n("Could not locate the debugging shell '%1'.").tqarg( shell_without_args ),
+ i18n("Could not locate the debugging shell '%1'.").arg( shell_without_args ),
i18n("Debugging Shell Not Found"), "gdb_error" );
return false;
}
@@ -955,7 +955,7 @@ void DebuggerPart::slotExamineCore()
if (coreFile.isNull())
return;
- mainWindow()->statusBar()->message(i18n("Examining core file %1").tqarg(coreFile), 1000);
+ mainWindow()->statusBar()->message(i18n("Examining core file %1").arg(coreFile), 1000);
startDebugger();
controller->slotCoreFile(coreFile);
@@ -976,7 +976,7 @@ void DebuggerPart::slotAttachProcess()
bool DebuggerPart::attachProcess(int pid)
{
- mainWindow()->statusBar()->message(i18n("Attaching to process %1").tqarg(pid), 1000);
+ mainWindow()->statusBar()->message(i18n("Attaching to process %1").arg(pid), 1000);
bool ret = startDebugger();
controller->slotAttachTo(pid);
@@ -1092,7 +1092,7 @@ void DebuggerPart::slotRefreshBPState( const Breakpoint& BP)
}
}
-void DebuggerPart::slottqStatus(const TQString &msg, int state)
+void DebuggerPart::slotStatus(const TQString &msg, int state)
{
TQString stateIndicator, stateIndicatorFull;
diff --git a/languages/cpp/debugger/debuggerpart.h b/languages/cpp/debugger/debuggerpart.h
index b201b15a..40877e29 100644
--- a/languages/cpp/debugger/debuggerpart.h
+++ b/languages/cpp/debugger/debuggerpart.h
@@ -95,7 +95,7 @@ private slots:
void slotRefreshBPState(const Breakpoint&);
- void slottqStatus(const TQString &msg, int state);
+ void slotStatus(const TQString &msg, int state);
void slotShowStep(const TQString &fileName, int lineNum);
void slotGotoSource(const TQString &fileName, int lineNum);
diff --git a/languages/cpp/debugger/debuggertracingdialogbase.ui b/languages/cpp/debugger/debuggertracingdialogbase.ui
index 51cfe410..faa68cd7 100644
--- a/languages/cpp/debugger/debuggertracingdialogbase.ui
+++ b/languages/cpp/debugger/debuggertracingdialogbase.ui
@@ -71,7 +71,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
diff --git a/languages/cpp/debugger/disassemblewidget.cpp b/languages/cpp/debugger/disassemblewidget.cpp
index 705185fd..dcb9ab6b 100644
--- a/languages/cpp/debugger/disassemblewidget.cpp
+++ b/languages/cpp/debugger/disassemblewidget.cpp
@@ -24,7 +24,7 @@
#include <tqdict.h>
#include <tqheader.h>
-#include <tqtextedit.h>
+#include <textedit.h>
#include <stdlib.h>
diff --git a/languages/cpp/debugger/disassemblewidget.h b/languages/cpp/debugger/disassemblewidget.h
index 73e743f7..93d3f44d 100644
--- a/languages/cpp/debugger/disassemblewidget.h
+++ b/languages/cpp/debugger/disassemblewidget.h
@@ -18,7 +18,7 @@
#include "mi/gdbmi.h"
-#include <tqtextedit.h>
+#include <textedit.h>
/***************************************************************************/
/***************************************************************************/
diff --git a/languages/cpp/debugger/framestackwidget.cpp b/languages/cpp/debugger/framestackwidget.cpp
index 2b8ae5a6..d7f50778 100644
--- a/languages/cpp/debugger/framestackwidget.cpp
+++ b/languages/cpp/debugger/framestackwidget.cpp
@@ -111,7 +111,7 @@ void FramestackWidget::slotSelectionChanged(TQListViewItem *thisItem)
if (frame->threadNo() != -1)
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(frame->threadNo()).ascii()));
+ .arg(frame->threadNo()).ascii()));
viewedThread_ = findThread(frame->threadNo());
getBacktrace(frame->frameNo(), frame->frameNo() + frameChunk_);
@@ -208,7 +208,7 @@ void FramestackWidget::getBacktrace(int min_frame, int max_frame)
maxFrame_ = max_frame;
controller_->addCommand(
- new GDBCommand(TQString("-stack-info-depth %1").tqarg(max_frame+1),
+ new GDBCommand(TQString("-stack-info-depth %1").arg(max_frame+1),
this,
&FramestackWidget::handleStackDepth));
}
@@ -224,7 +224,7 @@ void FramestackWidget::handleStackDepth(const GDBMI::ResultRecord& r)
//add the following command to the front, so noone switches threads in between
controller_->addCommandToFront(
new GDBCommand(TQString("-stack-list-frames %1 %2")
- .tqarg(minFrame_).tqarg(maxFrame_),
+ .arg(minFrame_).arg(maxFrame_),
this, &FramestackWidget::parseGDBBacktraceList));
}
@@ -236,7 +236,7 @@ void FramestackWidget::getBacktraceForThread(int threadNo)
// Switch to the target thread.
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(threadNo).ascii()));
+ .arg(threadNo).ascii()));
viewedThread_ = findThread(threadNo);
}
@@ -248,7 +248,7 @@ void FramestackWidget::getBacktraceForThread(int threadNo)
// Switch back to the original thread.
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(currentThread).ascii()));
+ .arg(currentThread).ascii()));
}
}
@@ -274,13 +274,13 @@ void FramestackWidget::handleThreadList(const GDBMI::ResultRecord& r)
TQString id = ids.results[i]->value->literal();
controller_->addCommand(
- new GDBCommand(TQString("-thread-select %1").tqarg(id).ascii(),
+ new GDBCommand(TQString("-thread-select %1").arg(id).ascii(),
this, &FramestackWidget::handleThread));
}
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(controller_->currentThread()).ascii()));
+ .arg(controller_->currentThread()).ascii()));
}
// Get backtrace for the current thread. We need to do this
@@ -558,7 +558,7 @@ ThreadStackItem::ThreadStackItem(FramestackWidget *parent, unsigned threadNo)
: TQListViewItem(parent),
threadNo_(threadNo)
{
- setText(0, i18n("Thread %1").tqarg(threadNo_));
+ setText(0, i18n("Thread %1").arg(threadNo_));
setExpandable(true);
}
diff --git a/languages/cpp/debugger/gdbbreakpointwidget.cpp b/languages/cpp/debugger/gdbbreakpointwidget.cpp
index 8626a3e1..146ed57b 100644
--- a/languages/cpp/debugger/gdbbreakpointwidget.cpp
+++ b/languages/cpp/debugger/gdbbreakpointwidget.cpp
@@ -37,7 +37,7 @@
#include <tqtooltip.h>
#include <tqwhatsthis.h>
#include <tqvbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqcheckbox.h>
@@ -56,7 +56,7 @@ enum Column {
Control = 0,
Enable = 1,
Type = 2,
- tqStatus = 3,
+ Status = 3,
Location = 4,
Condition = 5,
IgnoreCount = 6,
@@ -161,7 +161,7 @@ void BreakpointTableRow::setRow()
TQString status=m_breakpoint->statusDisplay(m_activeFlag);
- table()->setText(row(), tqStatus, status);
+ table()->setText(row(), Status, status);
table()->setText(row(), Condition, m_breakpoint->conditional());
table()->setText(row(), IgnoreCount, TQString::number(m_breakpoint->ignoreCount() ));
table()->setText(row(), Hits, TQString::number(m_breakpoint->hits() ));
@@ -183,7 +183,7 @@ void BreakpointTableRow::setRow()
table()->setText(row(), Type, displayType);
table()->adjustColumn(Type);
- table()->adjustColumn(tqStatus);
+ table()->adjustColumn(Status);
table()->adjustColumn(Location);
table()->adjustColumn(Hits);
table()->adjustColumn(IgnoreCount);
@@ -208,7 +208,7 @@ controller_(controller)
m_table->hideColumn(Control);
m_table->setColumnReadOnly(Type, true);
- m_table->setColumnReadOnly(tqStatus, true);
+ m_table->setColumnReadOnly(Status, true);
m_table->setColumnReadOnly(Hits, true);
m_table->setColumnWidth( Enable, 20);
@@ -216,7 +216,7 @@ controller_(controller)
header->setLabel( Enable, "" );
header->setLabel( Type, i18n("Type") );
- header->setLabel( tqStatus, i18n("Status") );
+ header->setLabel( Status, i18n("Status") );
header->setLabel( Location, i18n("Location") );
header->setLabel( Condition, i18n("Condition") );
header->setLabel( IgnoreCount, i18n("Ignore Count") );
@@ -377,10 +377,10 @@ void GDBBreakpointWidget::slotWatchpointHit(int id,
"Address: 0x%2<br>"
"Old value: %3<br>"
"New value: %4")
- .tqarg(b->varName())
- .tqarg(b->address(), 0, 16)
- .tqarg(oldValue)
- .tqarg(newValue));
+ .arg(b->varName())
+ .arg(b->address(), 0, 16)
+ .arg(oldValue)
+ .arg(newValue));
}
/***************************************************************************/
@@ -1213,7 +1213,7 @@ TQWidget* ComplexEditCell::createEditor() const
{
TQHBox* box = new TQHBox( table()->viewport() );
box->setPaletteBackgroundColor(
- table()->tqpalette().active().highlight());
+ table()->palette().active().highlight());
label_ = new TQLabel(text(), box, "label");
label_->setBackgroundMode(TQt::PaletteHighlight);
@@ -1225,16 +1225,16 @@ TQWidget* ComplexEditCell::createEditor() const
TQPalette p = label_->palette();
p.setColor(TQPalette::Active, TQColorGroup::Foreground,
- table()->tqpalette().active().highlightedText());
+ table()->palette().active().highlightedText());
p.setColor(TQPalette::Inactive, TQColorGroup::Foreground,
- table()->tqpalette().active().highlightedText());
+ table()->palette().active().highlightedText());
label_->setPalette(p);
TQPushButton* b = new TQPushButton("...", box);
// This is exactly what is done in TQDesigner source in the
// similar context. Haven't had any success making the good look
- // with tqlayout, I suppose that tqsizeHint for button is always larger
+ // with layout, I suppose that sizeHint for button is always larger
// than 20.
b->setFixedWidth( 20 );
diff --git a/languages/cpp/debugger/gdbcommand.cpp b/languages/cpp/debugger/gdbcommand.cpp
index c6c4bbc3..b5412dc0 100644
--- a/languages/cpp/debugger/gdbcommand.cpp
+++ b/languages/cpp/debugger/gdbcommand.cpp
@@ -105,7 +105,7 @@ ModifyBreakpointCommand::cmdToSend()
if (bp_->dbgId() > 0)
{
TQString s(initialString());
- s = s.tqarg(bp_->dbgId()) + "\n";
+ s = s.arg(bp_->dbgId()) + "\n";
return s.local8Bit();
}
else
diff --git a/languages/cpp/debugger/gdbcontroller.cpp b/languages/cpp/debugger/gdbcontroller.cpp
index ab7ffe69..b0c3171e 100644
--- a/languages/cpp/debugger/gdbcontroller.cpp
+++ b/languages/cpp/debugger/gdbcontroller.cpp
@@ -294,7 +294,7 @@ void GDBController::queueCmd(GDBCommand *cmd, enum queue_where queue_where)
KMessageBox::information(
0,
i18n("<b>Gdb command sent when debugger is not running</b><br>"
- "The command was:<br> %1").tqarg(cmd->initialString()),
+ "The command was:<br> %1").arg(cmd->initialString()),
i18n("Internal error"), "gdb_error");
return;
}
@@ -320,7 +320,7 @@ void GDBController::queueCmd(GDBCommand *cmd, enum queue_where queue_where)
<< (stateReloadInProgress_ ? " (state reloading)\n" : "\n");
setStateOn(s_dbgBusy);
- emit dbgtqStatus("", state_);
+ emit dbgStatus("", state_);
raiseEvent(debugger_busy);
executeCmd();
@@ -409,7 +409,7 @@ void GDBController::executeCmd()
else
emit gdbInternalCommandStdout( prettyCmd.latin1() );
- emit dbgtqStatus ("", state_);
+ emit dbgStatus ("", state_);
}
// **************************************************************************
@@ -500,7 +500,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
if (reason == "exited-signalled")
{
programNoApp(i18n("Exited on signal %1")
- .tqarg(r["signal-name"].literal()), false);
+ .arg(r["signal-name"].literal()), false);
// FIXME: figure out why this variable is needed.
programHasExited_ = true;
state_reload_needed = false;
@@ -540,7 +540,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
// or whatever).
setStateOff(s_explicitBreakInto);
- emit dbgtqStatus("Application interrupted", state_);
+ emit dbgStatus("Application interrupted", state_);
// Will show the source line in the code
// handling non-special stop kinds, below.
}
@@ -554,7 +554,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
// that'll end the program.
KMessageBox::information(0,
i18n("Program received signal %1 (%2)")
- .tqarg(name).tqarg(user_name),
+ .arg(name).arg(user_name),
i18n("Received signal"));
}
}
@@ -592,7 +592,7 @@ void GDBController::reloadProgramState()
maybeAnnounceWatchpointHit();
}
- emit dbgtqStatus ("", state_);
+ emit dbgStatus ("", state_);
// We're always at frame zero when the program stops
// and we must reset the active flag
@@ -648,7 +648,7 @@ void GDBController::programNoApp(const TQString &msg, bool msgBox)
if (msgBox)
KMessageBox::information(0, i18n("gdb message:\n")+msg,"Warning", "gdb_error");
- emit dbgtqStatus (msg, state_);
+ emit dbgStatus (msg, state_);
/* Also show message in gdb window, so that users who
prefer to look at gdb window know what's up. */
emit gdbUserCommandStdout(msg.ascii());
@@ -716,9 +716,9 @@ void GDBController::handleMiFileListExecSourceFile(const GDBMI::ResultRecord& r)
"Command was: %1\n"
"Response is: %2\n"
"Invalid response kind: \"%3\"")
- .tqarg(currentCmd_->rawDbgCommand())
- .tqarg(buf)
- .tqarg(r.reason),
+ .arg(currentCmd_->rawDbgCommand())
+ .arg(buf)
+ .arg(r.reason),
i18n("Invalid gdb reply"), "gdb_error");
#endif
}
@@ -755,7 +755,7 @@ void GDBController::maybeAnnounceWatchpointHit()
}
else if (last_stop_reason == "read-watchpoint-trigger")
{
- emit dbgtqStatus ("Read watchpoint triggered", state_);
+ emit dbgStatus ("Read watchpoint triggered", state_);
}
}
}
@@ -846,14 +846,14 @@ bool GDBController::start(const TQString& shell, const DomUtil::PairList& run_en
i18n("<b>Could not start debugger.</b>"
"<p>Could not run '%1'. "
"Make sure that the path name is specified correctly."
- ).tqarg(dbgProcess_->args()[0].data()),
+ ).arg(dbgProcess_->args()[0].data()),
i18n("Could not start debugger"), "gdb_error");
return false;
}
setStateOff(s_dbgNotStarted);
- emit dbgtqStatus ("", state_);
+ emit dbgStatus ("", state_);
saw_gdb_prompt_ = false;
@@ -1043,7 +1043,7 @@ void GDBController::slotStopDebugger()
gdbOutput_ = "";
setState(s_dbgNotStarted | s_appNotStarted);
- emit dbgtqStatus (i18n("Debugger stopped"), state_);
+ emit dbgStatus (i18n("Debugger stopped"), state_);
raiseEvent(debugger_exited);
}
@@ -1159,7 +1159,7 @@ void GDBController::slotRun()
" %1\n"
"<br>does not exist. Check that you have specified "
"the right application in the debugger configuration."
- ).tqarg(app.fileName()),
+ ).arg(app.fileName()),
i18n("Application does not exist"));
// FIXME: after this, KDevelop will still show that debugger
@@ -1176,7 +1176,7 @@ void GDBController::slotRun()
"<p>The application does not have the executable bit set. "
"Try rebuilding the project, or change permissions "
"manually."
- ).tqarg(app.fileName()),
+ ).arg(app.fileName()),
i18n("Could not run application"));
slotStopDebugger();
}
@@ -1324,11 +1324,11 @@ void GDBController::selectFrame(int frameNo, int threadNo)
{
if (viewedThread_ != threadNo)
queueCmd(new GDBCommand(
- TQString("-thread-select %1").tqarg(threadNo).ascii()));
+ TQString("-thread-select %1").arg(threadNo).ascii()));
}
queueCmd(new GDBCommand(
- TQString("-stack-select-frame %1").tqarg(frameNo).ascii()));
+ TQString("-stack-select-frame %1").arg(frameNo).ascii()));
// Will emit the 'thread_or_frame_changed' event.
queueCmd(new GDBCommand("-stack-info-frame",
@@ -1352,7 +1352,7 @@ void GDBController::defaultErrorHandler(const GDBMI::ResultRecord& result)
if (msg.contains("No such process"))
{
setState(s_appNotStarted|s_programExited);
- emit dbgtqStatus (i18n("Process exited"), state_);
+ emit dbgStatus (i18n("Process exited"), state_);
raiseEvent(program_exited);
return;
}
@@ -1590,7 +1590,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
"<p>The debugger component encountered an internal error while "
"processing a reply from gdb. Please submit a bug report."),
i18n("The exception is: %1\n"
- "The MI response is: %2").tqarg(e.what()).tqarg(reply.data()),
+ "The MI response is: %2").arg(e.what()).arg(reply.data()),
i18n("Internal debugger error"));
destroyCurrentCommand();
@@ -1629,7 +1629,7 @@ void GDBController::commandDone()
{
kdDebug(9012) << "No more commands\n";
setStateOff(s_dbgBusy);
- emit dbgtqStatus("", state_);
+ emit dbgStatus("", state_);
raiseEvent(debugger_ready);
}
}
@@ -1688,7 +1688,7 @@ void GDBController::raiseEvent(event_t e)
void GDBController::slotDbgStderr(KProcess *proc, char *buf, int buflen)
{
// At the moment, just drop a message out and redirect
- kdDebug(9012) << "STDERR: " << TQString::tqfromLatin1(buf, buflen+1) << endl;
+ kdDebug(9012) << "STDERR: " << TQString::fromLatin1(buf, buflen+1) << endl;
slotDbgStdout(proc, buf, buflen);
}
@@ -1722,7 +1722,7 @@ void GDBController::slotDbgProcessExited(KProcess* process)
destroyCmds();
setState(s_dbgNotStarted|s_appNotStarted|s_programExited);
- emit dbgtqStatus (i18n("Process exited"), state_);
+ emit dbgStatus (i18n("Process exited"), state_);
emit gdbUserCommandStdout("(gdb) Process exited\n");
}
@@ -1743,14 +1743,14 @@ void GDBController::slotUserGDBCmd(const TQString& cmd)
// raiseEvent(program_state_changed);
}
-void GDBController::explainDebuggertqStatus()
+void GDBController::explainDebuggerStatus()
{
TQString information("%1 commands in queue\n"
"%2 commands being processed by gdb\n"
"Debugger state: %3\n");
information =
- information.tqarg(cmdList_.count()).tqarg(currentCmd_ ? 1 : 0)
- .tqarg(state_);
+ information.arg(cmdList_.count()).arg(currentCmd_ ? 1 : 0)
+ .arg(state_);
if (currentCmd_)
{
@@ -1758,8 +1758,8 @@ void GDBController::explainDebuggertqStatus()
"Current command text: '%2'\n"
"Current command origianl text: '%3'\n");
- extra = extra.tqarg(
- typeid(*currentCmd_).name()).tqarg(currentCmd_->cmdToSend()).
+ extra = extra.arg(
+ typeid(*currentCmd_).name()).arg(currentCmd_->cmdToSend()).
arg(currentCmd_->initialString());
information += extra;
}
diff --git a/languages/cpp/debugger/gdbcontroller.h b/languages/cpp/debugger/gdbcontroller.h
index 6ea27f41..3bc0020d 100644
--- a/languages/cpp/debugger/gdbcontroller.h
+++ b/languages/cpp/debugger/gdbcontroller.h
@@ -250,7 +250,7 @@ public slots:
// Pops up a dialog box with some hopefully
// detailed information about which state debugger
// is in, which commands were sent and so on.
- void explainDebuggertqStatus();
+ void explainDebuggerStatus();
protected slots:
diff --git a/languages/cpp/debugger/gdboutputwidget.cpp b/languages/cpp/debugger/gdboutputwidget.cpp
index c0157463..82385c72 100644
--- a/languages/cpp/debugger/gdboutputwidget.cpp
+++ b/languages/cpp/debugger/gdboutputwidget.cpp
@@ -25,12 +25,12 @@
#include <kpopupmenu.h>
#include <tqlabel.h>
-#include <tqlayout.h>
-#include <tqtextedit.h>
+#include <layout.h>
+#include <textedit.h>
#include <tqtoolbutton.h>
#include <tqtooltip.h>
#include <tqapplication.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <tqdom.h>
@@ -62,7 +62,7 @@ GDBOutputWidget::GDBOutputWidget( TQWidget *parent, const char *name) :
userGDBCmdEntry->setStretchFactor(m_userGDBCmdEditor, 1);
m_Interrupt = new TQToolButton( this, "add breakpoint" );
- m_Interrupt->tqsetSizePolicy ( TQSizePolicy ( (TQSizePolicy::SizeType)0,
+ m_Interrupt->setSizePolicy ( TQSizePolicy ( (TQSizePolicy::SizeType)0,
( TQSizePolicy::SizeType)0,
0,
0,
@@ -76,7 +76,7 @@ GDBOutputWidget::GDBOutputWidget( TQWidget *parent, const char *name) :
topLayout->addWidget(m_gdbView, 10);
topLayout->addLayout(userGDBCmdEntry);
- slotDbgtqStatus( "", s_dbgNotStarted);
+ slotDbgStatus( "", s_dbgNotStarted);
connect( m_userGDBCmdEditor, TQT_SIGNAL(returnPressed()), TQT_SLOT(slotGDBCmd()) );
connect( m_Interrupt, TQT_SIGNAL(clicked()), TQT_SIGNAL(breakInto()));
@@ -257,7 +257,7 @@ void GDBOutputWidget::flushPending()
/***************************************************************************/
-void GDBOutputWidget::slotDbgtqStatus(const TQString &, int statusFlag)
+void GDBOutputWidget::slotDbgStatus(const TQString &, int statusFlag)
{
if (statusFlag & s_dbgNotStarted)
{
@@ -328,7 +328,7 @@ TQPopupMenu* OutputText::createPopupMenu(const TQPoint&)
TQT_SLOT(toggleShowInternalCommands()));
popup->setItemChecked(id, parent_->showInternalCommands_);
- popup->tqsetWhatsThis(
+ popup->setWhatsThis(
id,
i18n(
"Controls if commands issued internally by KDevelop "
@@ -356,8 +356,8 @@ void OutputText::copyAll()
// Make sure the text is pastable both with Ctrl-C and with
// middle click.
- TQApplication::tqclipboard()->setText(text, TQClipboard::Clipboard);
- TQApplication::tqclipboard()->setText(text, TQClipboard::Selection);
+ TQApplication::clipboard()->setText(text, TQClipboard::Clipboard);
+ TQApplication::clipboard()->setText(text, TQClipboard::Selection);
}
void OutputText::toggleShowInternalCommands()
diff --git a/languages/cpp/debugger/gdboutputwidget.h b/languages/cpp/debugger/gdboutputwidget.h
index 28ffb8bc..de7704f1 100644
--- a/languages/cpp/debugger/gdboutputwidget.h
+++ b/languages/cpp/debugger/gdboutputwidget.h
@@ -19,7 +19,7 @@
#define _GDBOUTPUTWIDGET_H_
#include <tqwidget.h>
-#include <tqtextedit.h>
+#include <textedit.h>
#include <tqtimer.h>
#include <tqstringlist.h>
@@ -50,7 +50,7 @@ public slots:
void slotInternalCommandStdout(const char* line);
void slotUserCommandStdout(const char* line);
void slotReceivedStderr(const char* line);
- void slotDbgtqStatus (const TQString &status, int statusFlag);
+ void slotDbgStatus (const TQString &status, int statusFlag);
void slotGDBCmd();
diff --git a/languages/cpp/debugger/memviewdlg.cpp b/languages/cpp/debugger/memviewdlg.cpp
index 3b69c206..217f09fe 100644
--- a/languages/cpp/debugger/memviewdlg.cpp
+++ b/languages/cpp/debugger/memviewdlg.cpp
@@ -27,14 +27,14 @@
#include <kiconloader.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqmultilineedit.h>
#include <tqpushbutton.h>
#include <tqvariant.h>
#include <tqpopupmenu.h>
#include <tqhbox.h>
#include <tqtoolbox.h>
-#include <tqtextedit.h>
+#include <textedit.h>
#include <kmessagebox.h>
@@ -84,7 +84,7 @@ namespace GDBDebugger
{
TQVBoxLayout* l = new TQVBoxLayout(this);
- // Grid tqlayout: labels + address field
+ // Grid layout: labels + address field
TQGridLayout* gl = new TQGridLayout(l);
gl->setColSpacing(0, 2);
@@ -263,8 +263,8 @@ namespace GDBDebugger
new
GDBCommand(
TQString("-data-read-memory %1 x 1 1 %2")
- .tqarg(rangeSelector_->startAddressLineEdit->text())
- .tqarg(size).ascii(),
+ .arg(rangeSelector_->startAddressLineEdit->text())
+ .arg(size).ascii(),
this,
&MemoryView::memoryRead));
}
@@ -280,7 +280,7 @@ namespace GDBDebugger
start_ = startAsString_.toUInt(0, 0);
setCaption(TQString("%1 (%2 bytes)")
- .tqarg(startAsString_).tqarg(amount_));
+ .arg(startAsString_).arg(amount_));
emit captionChanged(caption());
KHE::BytesEditInterface* bytesEditor
@@ -328,9 +328,9 @@ namespace GDBDebugger
controller_->addCommand(
new GDBCommand(
TQString("set *(char*)(%1 + %2) = %3")
- .tqarg(start_)
- .tqarg(i)
- .tqarg(TQString::number(data_[i]))));
+ .arg(start_)
+ .arg(i)
+ .arg(TQString::number(data_[i]))));
}
}
@@ -374,7 +374,7 @@ namespace GDBDebugger
new
GDBCommand(
TQString("-data-read-memory %1 x 1 1 %2")
- .tqarg(start_).tqarg(amount_).ascii(),
+ .arg(start_).arg(amount_).ascii(),
this,
&MemoryView::memoryRead));
}
diff --git a/languages/cpp/debugger/variablewidget.h b/languages/cpp/debugger/variablewidget.h
index cb8ffb0f..da885216 100644
--- a/languages/cpp/debugger/variablewidget.h
+++ b/languages/cpp/debugger/variablewidget.h
@@ -186,16 +186,16 @@ private:
/***************************************************************************/
/***************************************************************************/
-/** List view item that can 'trim' outdated tqchildren.
+/** List view item that can 'trim' outdated children.
- The instances of this class hold a number of tqchildren corresponding
+ The instances of this class hold a number of children corresponding
to variables. When program state changes, such as after a step in source,
some variable values can change, and some variables can go out of scope.
We need
- highlight modified variables
- remove gone variables
- We could just remove all tqchildren and repopulate the list from
+ We could just remove all children and repopulate the list from
the data from debugger, but then we'd loose information about previous
variable values.
@@ -286,7 +286,7 @@ public:
/** Recursively clears the varobjName_ field, making
*this completely disconnected from gdb.
- Automatically makes *this and tqchildren disables,
+ Automatically makes *this and children disables,
since there's no possible interaction with unhooked
object.
*/
@@ -300,7 +300,7 @@ public:
format_t formatFromGdbModifier(char c) const;
/** Clears highliting for this variable and
- all its tqchildren. */
+ all its children. */
void clearHighlight();
/** Sets new top-level textual value of this variable.
@@ -333,7 +333,7 @@ private:
- sets varobjName_ to 'name'
- sets format, if it's not default one
- gets initial value
- - if item is open, gets tqchildren.
+ - if item is open, gets children.
*/
void setVarobjName(const TQString& name);
@@ -348,12 +348,12 @@ private:
int column, int width, int align );
void varobjCreated(const GDBMI::ResultRecord& r);
void valueDone(const GDBMI::ResultRecord& r);
- void tqchildrenDone(const GDBMI::ResultRecord& r);
- void tqchildrenOfFakesDone(const GDBMI::ResultRecord& r);
+ void childrenDone(const GDBMI::ResultRecord& r);
+ void childrenOfFakesDone(const GDBMI::ResultRecord& r);
void handleCurrentAddress(const TQValueVector<TQString>& lines);
void handleType(const TQValueVector<TQString>& lines);
- void createChildren(const GDBMI::ResultRecord& r, bool tqchildren_of_fake);
+ void createChildren(const GDBMI::ResultRecord& r, bool children_of_fake);
/** Called to handle the output of the cli print command.
*/
@@ -391,7 +391,7 @@ private:
static int varobjIndex;
int numChildren_;
- bool tqchildrenFetched_;
+ bool childrenFetched_;
TQString currentAddress_;
TQString lastObtainedAddress_;
diff --git a/languages/cpp/debugger/variablewidget.cpp b/languages/cpp/debugger/variablewidget.cpp
index a8c9f594..4adf33c2 100644
--- a/languages/cpp/debugger/variablewidget.cpp
+++ b/languages/cpp/debugger/variablewidget.cpp
@@ -26,7 +26,7 @@
#include <tqheader.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqhbox.h>
#include <tqpainter.h>
#include <tqpushbutton.h>
@@ -36,7 +36,7 @@
#include <klocale.h>
#include <tqpoint.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <kapplication.h>
#include <kmessagebox.h>
@@ -47,14 +47,14 @@
/** The variables widget is passive, and is invoked by the rest of the
code via two main slots:
- - slotDbgtqStatus
+ - slotDbgStatus
- slotCurrentFrame
The first is received the program status changes and the second is
recieved after current frame in the debugger can possibly changes.
The widget has a list item for each frame/thread combination, with
- variables as tqchildren. However, at each moment only one item is shown.
+ variables as children. However, at each moment only one item is shown.
When handling the slotCurrentFrame, we check if variables for the
current frame are available. If yes, we simply show the corresponding item.
Otherwise, we fetch the new data from debugger.
@@ -338,7 +338,7 @@ void VariableTree::slotContextMenu(KListView *, TQListViewItem *item)
controller_->addCommand(
new GDBCommand(
TQString("-data-evaluate-expression &%1")
- .tqarg(var->gdbExpression()),
+ .arg(var->gdbExpression()),
this,
&VariableTree::handleAddressComputed,
true /*handles error*/));
@@ -505,8 +505,8 @@ void VariableTree::updateCurrentFrame()
controller_->addCommand(
new GDBCommand(TQString("-stack-list-arguments 0 %1 %2")
- .tqarg(controller_->currentFrame())
- .tqarg(controller_->currentFrame())
+ .arg(controller_->currentFrame())
+ .arg(controller_->currentFrame())
.ascii(),
this,
&VariableTree::argumentsReady));
@@ -607,7 +607,7 @@ void VariableTree::maybeTip(const TQPoint &p)
VarItem * item = dynamic_cast<VarItem*>( itemAt( p ) );
if ( item )
{
- TQRect r = tqitemRect( item );
+ TQRect r = itemRect( item );
if ( r.isValid() )
tip( r, item->tipText() );
}
@@ -882,8 +882,8 @@ void VarItem::handleCliPrint(const TQValueVector<TQString>& lines)
{
controller_->addCommand(
new GDBCommand(TQString("-var-create %1 * \"%2\"")
- .tqarg(varobjName_)
- .tqarg(r.cap(1)),
+ .arg(varobjName_)
+ .arg(r.cap(1)),
this,
&VarItem::varobjCreated,
// On initial create, errors get reported
@@ -988,7 +988,7 @@ void VariableTree::keyPressEvent(TQKeyEvent* e)
void VariableTree::copyToClipboard(TQListViewItem* item)
{
- TQClipboard *qb = KApplication::tqclipboard();
+ TQClipboard *qb = KApplication::clipboard();
TQString text = item->text( 1 );
qb->setText( text, TQClipboard::Clipboard );
@@ -1078,7 +1078,7 @@ VarItem::VarItem(TrimmableItem *parent,
oldSpecialRepresentationSet_(false),
format_(natural),
numChildren_(0),
- tqchildrenFetched_(false),
+ childrenFetched_(false),
updateUnconditionally_(false),
frozen_(frozen),
initialCreation_(true),
@@ -1123,7 +1123,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
oldSpecialRepresentationSet_(false),
format_(format),
numChildren_(0),
- tqchildrenFetched_(false),
+ childrenFetched_(false),
updateUnconditionally_(false),
frozen_(false),
initialCreation_(false),
@@ -1146,7 +1146,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
controller_ = varTree()->controller();
// Set type and tqchildren.
originalValueType_ = varobj["type"].literal();
numChildren_ = varobj["numchild"].literal().toInt();
setExpandable(numChildren_ != 0);
@@ -1159,7 +1159,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
void VarItem::createVarobj()
{
TQString old = varobjName_;
- varobjName_ = TQString("KDEV%1").tqarg(varobjIndex++);
+ varobjName_ = TQString("KDEV%1").arg(varobjIndex++);
emit varobjNameChange(old, varobjName_);
if (frozen_)
@@ -1169,7 +1169,7 @@ void VarItem::createVarobj()
// variable and we create variable object from that.
controller_->addCommand(
new CliCommand(
- TQString("print %1").tqarg(expression_),
+ TQString("print %1").arg(expression_),
this,
&VarItem::handleCliPrint));
}
@@ -1177,7 +1177,7 @@ void VarItem::createVarobj()
{
controller_->addCommand(
new CliCommand(
- TQString("print /x &%1").tqarg(expression_),
+ TQString("print /x &%1").arg(expression_),
this,
&VarItem::handleCurrentAddress,
true));
@@ -1186,8 +1186,8 @@ void VarItem::createVarobj()
// Need to quote expression, otherwise gdb won't like
// spaces inside it.
new GDBCommand(TQString("-var-create %1 * \"%2\"")
- .tqarg(varobjName_)
- .tqarg(expression_),
+ .arg(varobjName_)
+ .arg(expression_),
this,
&VarItem::varobjCreated,
initialCreation_ ? false : true));
@@ -1209,7 +1209,7 @@ void VarItem::varobjCreated(const GDBMI::ResultRecord& r)
originalValueType_ = r["type"].literal();
if (!oldType.isEmpty() && oldType != originalValueType_)
{
// Type changed, the tqchildren might be no longer valid,
// so delete them.
for(TQListViewItem* child = firstChild(); child; )
{
@@ -1239,7 +1239,7 @@ void VarItem::setVarobjName(const TQString& name)
{
controller_->addCommand(
new GDBCommand(TQString("-var-set-format \"%1\" %2")
- .tqarg(varobjName_).tqarg(varobjFormatName())));
+ .arg(varobjName_).arg(varobjFormatName())));
}
// Get the initial value.
@@ -1247,7 +1247,7 @@ void VarItem::setVarobjName(const TQString& name)
if (isOpen())
{
// This regets tqchildren list.
setOpen(true);
}
}
@@ -1333,18 +1333,18 @@ void VarItem::valueDone(const GDBMI::ResultRecord& r)
}
void VarItem::createChildren(const GDBMI::ResultRecord& r,
- bool tqchildren_of_fake)
+ bool children_of_fake)
{
- const GDBMI::Value& tqchildren = r["tqchildren"];
+ const GDBMI::Value& children = r["children"];
/* In order to figure out which variable objects correspond
to base class subobject, we first must detect if *this
is a structure type. We use present of 'public'/'private'/'protected'
fake child as an indicator. */
bool structureType = false;
- if (!tqchildren_of_fake && tqchildren.size() > 0)
+ if (!children_of_fake && children.size() > 0)
{
- TQString exp = tqchildren[0]["exp"].literal();
+ TQString exp = children[0]["exp"].literal();
bool ok = false;
exp.toInt(&ok);
if (!ok || exp[0] != '*')
@@ -1353,23 +1353,23 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
}
}
- for (unsigned i = 0; i < tqchildren.size(); ++i)
+ for (unsigned i = 0; i < children.size(); ++i)
{
- TQString exp = tqchildren[i]["exp"].literal();
+ TQString exp = children[i]["exp"].literal();
// For artificial accessibility nodes,
// fetch their tqchildren.
if (exp == "public" || exp == "protected" || exp == "private")
{
- TQString name = tqchildren[i]["name"].literal();
+ TQString name = children[i]["name"].literal();
controller_->addCommand(new GDBCommand(
- "-var-list-tqchildren \"" +
+ "-var-list-children \"" +
name + "\"",
this,
- &VarItem::tqchildrenOfFakesDone));
+ &VarItem::childrenOfFakesDone));
}
else
{
/* All tqchildren of structures that are not artifical
are base subobjects. */
bool baseObject = structureType;
@@ -1388,7 +1388,7 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
}
if (existing)
{
- existing->setVarobjName(tqchildren[i]["name"].literal());
+ existing->setVarobjName(children[i]["name"].literal());
}
else
{
@@ -1396,20 +1396,20 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
<< exp << " " << baseObject << "\n";
// Propagate format from parent.
VarItem* v = 0;
- v = new VarItem(this, tqchildren[i], format_, baseObject);
+ v = new VarItem(this, children[i], format_, baseObject);
}
}
}
}
-void VarItem::tqchildrenDone(const GDBMI::ResultRecord& r)
+void VarItem::childrenDone(const GDBMI::ResultRecord& r)
{
createChildren(r, false);
- tqchildrenFetched_ = true;
+ childrenFetched_ = true;
}
-void VarItem::tqchildrenOfFakesDone(const GDBMI::ResultRecord& r)
+void VarItem::childrenOfFakesDone(const GDBMI::ResultRecord& r)
{
createChildren(r, true);
}
@@ -1603,8 +1603,8 @@ void VarItem::updateValue()
void VarItem::setValue(const TQString& new_value)
{
controller_->addCommand(
- new GDBCommand(TQString("-var-assign \"%1\" %2").tqarg(varobjName_)
- .tqarg(new_value)));
+ new GDBCommand(TQString("-var-assign \"%1\" %2").arg(varobjName_)
+ .arg(new_value)));
// And immediately reload it from gdb,
// so that it's display format is the one gdb uses,
@@ -1624,7 +1624,7 @@ void VarItem::updateSpecialRepresentation(const TQString& xs)
s = s.mid(i+2);
}
// A hack to nicely display TQStrings. The content of TQString is tqunicode
// for for ASCII only strings we get ascii character mixed with \000.
// Remove those \000 now.
@@ -1661,14 +1661,14 @@ void VarItem::recreateLocallyMaybe()
{
controller_->addCommand(
new CliCommand(
- TQString("print /x &%1").tqarg(expression_),
+ TQString("print /x &%1").arg(expression_),
this,
&VarItem::handleCurrentAddress,
true));
controller_->addCommand(
new CliCommand(
- TQString("whatis %1").tqarg(expression_),
+ TQString("whatis %1").arg(expression_),
this,
&VarItem::handleType));
}
@@ -1688,12 +1688,12 @@ void VarItem::setOpen(bool open)
{
TQListViewItem::setOpen(open);
- if (open && !tqchildrenFetched_)
+ if (open && !childrenFetched_)
{
controller_->addCommand(new GDBCommand(
- "-var-list-tqchildren \"" + varobjName_ + "\"",
+ "-var-list-children \"" + varobjName_ + "\"",
this,
- &VarItem::tqchildrenDone));
+ &VarItem::childrenDone));
}
}
@@ -1712,7 +1712,7 @@ bool VarItem::handleSpecialTypes()
return false;
varTree->controller()->addCommand(
new ResultlessCommand(TQString("print $kdev_d=%1.d")
- .tqarg(gdbExpression()),
+ .arg(gdbExpression()),
true /* ignore error */));
if (varTree->controller()->qtVersion() >= 4)
@@ -1736,7 +1736,7 @@ bool VarItem::handleSpecialTypes()
else
varTree->controller()->addCommand(
new ValueSpecialRepresentationCommand(
- this, "print ($kdev_s>0) ? (*((char*)&$kdev_d.tqunicode[0])@$kdev_s) : \"\""));
+ this, "print ($kdev_s>0) ? (*((char*)&$kdev_d.unicode[0])@$kdev_s) : \"\""));
return true;
}
@@ -1760,7 +1760,7 @@ void VarItem::setFormat(format_t f)
if (numChildren_)
{
// If variable has tqchildren, change format for tqchildren.
// - for structures, that's clearly right
// - for arrays, that's clearly right
// - for pointers, this can be confusing, but nobody ever wants to
@@ -1775,7 +1775,7 @@ void VarItem::setFormat(format_t f)
{
controller_->addCommand(
new GDBCommand(TQString("-var-set-format \"%1\" %2")
- .tqarg(varobjName_).tqarg(varobjFormatName())));
+ .arg(varobjName_).arg(varobjFormatName())));
updateValue();
}
@@ -1853,7 +1853,7 @@ void VarItem::paintCell(TQPainter *p, const TQColorGroup &cg,
if (!alive_)
{
/* Draw this as disabled. */
- TQListViewItem::paintCell(p, varTree()->TQWidget::tqpalette().disabled(),
+ TQListViewItem::paintCell(p, varTree()->TQWidget::palette().disabled(),
column, width, align);
}
else
@@ -1876,7 +1876,7 @@ VariableTree* VarItem::varTree() const
void VarItem::unhookFromGdb()
{
// Unhook tqchildren first, so that child varitems are deleted
// before parent. Strictly speaking, we can avoid calling
// -var-delete on child varitems, but that's a bit cheesy,
for(TQListViewItem* child = firstChild();
@@ -1886,7 +1886,7 @@ void VarItem::unhookFromGdb()
}
alive_ = false;
- tqchildrenFetched_ = false;
+ childrenFetched_ = false;
emit varobjNameChange(varobjName_, "");
@@ -1894,7 +1894,7 @@ void VarItem::unhookFromGdb()
{
controller_->addCommand(
new GDBCommand(
- TQString("-var-delete \"%1\"").tqarg(varobjName_)));
+ TQString("-var-delete \"%1\"").arg(varobjName_)));
}
varobjName_ = "";
@@ -1146,7 +1146,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
controller_ = varTree()->controller();
- // Set type and tqchildren.
+ // Set type and children.
originalValueType_ = varobj["type"].literal();
numChildren_ = varobj["numchild"].literal().toInt();
@@ -1209,7 +1209,7 @@ void VarItem::varobjCreated(const GDBMI::ResultRecord& r)
if (!oldType.isEmpty() && oldType != originalValueType_)
{
- // Type changed, the tqchildren might be no longer valid,
+ // Type changed, the children might be no longer valid,
// so delete them.
for(TQListViewItem* child = firstChild(); child; )
@@ -1247,7 +1247,7 @@ void VarItem::setVarobjName(const TQString& name)
if (isOpen())
{
- // This regets tqchildren list.
+ // This regets children list.
setOpen(true);
}
@@ -1353,23 +1353,23 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
// For artificial accessibility nodes,
- // fetch their tqchildren.
+ // fetch their children.
if (exp == "public" || exp == "protected" || exp == "private")
{
@@ -1353,23 +1353,23 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
else
{
- /* All tqchildren of structures that are not artifical
+ /* All children of structures that are not artifical
are base subobjects. */
bool baseObject = structureType;
@@ -1624,7 +1624,7 @@ void VarItem::updateSpecialRepresentation(const TQString& xs)
s = s.mid(i+2);
}
- // A hack to nicely display TQStrings. The content of TQString is tqunicode
+ // A hack to nicely display TQStrings. The content of TQString is unicode
// for for ASCII only strings we get ascii character mixed with \000.
// Remove those \000 now.
@@ -1760,7 +1760,7 @@ void VarItem::setFormat(format_t f)
if (numChildren_)
{
- // If variable has tqchildren, change format for tqchildren.
+ // If variable has children, change format for children.
// - for structures, that's clearly right
// - for arrays, that's clearly right
@@ -1876,7 +1876,7 @@ VariableTree* VarItem::varTree() const
void VarItem::unhookFromGdb()
{
- // Unhook tqchildren first, so that child varitems are deleted
+ // Unhook children first, so that child varitems are deleted
// before parent. Strictly speaking, we can avoid calling
// -var-delete on child varitems, but that's a bit cheesy,